@@ -133,6 +133,7 @@
 #include <Qt3DRender/qtexturegenerator.h>
 #include <Qt3DRender/qlinewidth.h>
 #include <Qt3DRender/qpolygonoffset.h>
+#include <Qt3DRender/qsetfence.h>
 #include <Qt3DRender/qnodraw.h>
 #include <Qt3DRender/qrenderstateset.h>
 #include <Qt3DRender/qbuffercapture.h>
@@ -140,6 +141,7 @@
 #include <Qt3DRender/qraycasterhit.h>
 #include <Qt3DRender/qlevelofdetail.h>
 #include <Qt3DRender/qclipplane.h>
+#include <Qt3DRender/qwaitfence.h>
 #include <Qt3DRender/qgeometryfactory.h>
 #include <Qt3DRender/qrendertarget.h>
 #include <Qt3DRender/qclearbuffers.h>
@@ -170,7 +172,7 @@
 
 // Type indices
 enum : int {
-    SBK_QT3DRENDER_IDX                                       = 2,
+    SBK_Qt3DRenderQT3DRENDER_IDX                             = 2,
     SBK_QT3DRENDER_PROPERTYREADERINTERFACE_IDX               = 3,
     SBK_QT3DRENDER_QABSTRACTFUNCTOR_IDX                      = 4,
     SBK_QT3DRENDER_QABSTRACTLIGHT_IDX                        = 5,
@@ -179,165 +181,172 @@ enum : int {
     SBK_QT3DRENDER_QABSTRACTRAYCASTER_RUNMODE_IDX            = 9,
     SBK_QT3DRENDER_QABSTRACTRAYCASTER_FILTERMODE_IDX         = 8,
     SBK_QT3DRENDER_QABSTRACTTEXTURE_IDX                      = 10,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_STATUS_IDX               = 15,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_TARGET_IDX               = 16,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_TEXTUREFORMAT_IDX        = 17,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_STATUS_IDX               = 16,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_TARGET_IDX               = 17,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_TEXTUREFORMAT_IDX        = 18,
     SBK_QT3DRENDER_QABSTRACTTEXTURE_FILTER_IDX               = 14,
     SBK_QT3DRENDER_QABSTRACTTEXTURE_CUBEMAPFACE_IDX          = 13,
     SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONFUNCTION_IDX   = 11,
     SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONMODE_IDX       = 12,
-    SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX                 = 18,
-    SBK_QT3DRENDER_QALPHACOVERAGE_IDX                        = 19,
-    SBK_QT3DRENDER_QALPHATEST_IDX                            = 20,
-    SBK_QT3DRENDER_QALPHATEST_ALPHAFUNCTION_IDX              = 21,
-    SBK_QT3DRENDER_QATTRIBUTE_IDX                            = 22,
-    SBK_QT3DRENDER_QATTRIBUTE_ATTRIBUTETYPE_IDX              = 23,
-    SBK_QT3DRENDER_QATTRIBUTE_VERTEXBASETYPE_IDX             = 24,
-    SBK_QT3DRENDER_QBLENDEQUATION_IDX                        = 25,
-    SBK_QT3DRENDER_QBLENDEQUATION_BLENDFUNCTION_IDX          = 26,
-    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_IDX               = 27,
-    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_BLENDING_IDX      = 28,
-    SBK_QT3DRENDER_QBLITFRAMEBUFFER_IDX                      = 29,
-    SBK_QT3DRENDER_QBLITFRAMEBUFFER_INTERPOLATIONMETHOD_IDX  = 30,
-    SBK_QT3DRENDER_QBUFFER_IDX                               = 31,
-    SBK_QT3DRENDER_QBUFFER_BUFFERTYPE_IDX                    = 33,
-    SBK_QT3DRENDER_QBUFFER_USAGETYPE_IDX                     = 34,
-    SBK_QT3DRENDER_QBUFFER_ACCESSTYPE_IDX                    = 32,
-    SBK_QT3DRENDER_QBUFFERCAPTURE_IDX                        = 35,
-    SBK_QT3DRENDER_QBUFFERDATAGENERATOR_IDX                  = 36,
-    SBK_QT3DRENDER_QCAMERA_IDX                               = 37,
-    SBK_QT3DRENDER_QCAMERA_CAMERATRANSLATIONOPTION_IDX       = 38,
-    SBK_QT3DRENDER_QCAMERALENS_IDX                           = 39,
-    SBK_QT3DRENDER_QCAMERALENS_PROJECTIONTYPE_IDX            = 40,
-    SBK_QT3DRENDER_QCAMERASELECTOR_IDX                       = 41,
-    SBK_QT3DRENDER_QCLEARBUFFERS_IDX                         = 42,
-    SBK_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX              = 43,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_HANDLETYPE_IDX           = 15,
+    SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX                 = 19,
+    SBK_QT3DRENDER_QALPHACOVERAGE_IDX                        = 20,
+    SBK_QT3DRENDER_QALPHATEST_IDX                            = 21,
+    SBK_QT3DRENDER_QALPHATEST_ALPHAFUNCTION_IDX              = 22,
+    SBK_QT3DRENDER_QATTRIBUTE_IDX                            = 23,
+    SBK_QT3DRENDER_QATTRIBUTE_ATTRIBUTETYPE_IDX              = 24,
+    SBK_QT3DRENDER_QATTRIBUTE_VERTEXBASETYPE_IDX             = 25,
+    SBK_QT3DRENDER_QBLENDEQUATION_IDX                        = 26,
+    SBK_QT3DRENDER_QBLENDEQUATION_BLENDFUNCTION_IDX          = 27,
+    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_IDX               = 28,
+    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_BLENDING_IDX      = 29,
+    SBK_QT3DRENDER_QBLITFRAMEBUFFER_IDX                      = 30,
+    SBK_QT3DRENDER_QBLITFRAMEBUFFER_INTERPOLATIONMETHOD_IDX  = 31,
+    SBK_QT3DRENDER_QBUFFER_IDX                               = 32,
+    SBK_QT3DRENDER_QBUFFER_BUFFERTYPE_IDX                    = 34,
+    SBK_QT3DRENDER_QBUFFER_USAGETYPE_IDX                     = 35,
+    SBK_QT3DRENDER_QBUFFER_ACCESSTYPE_IDX                    = 33,
+    SBK_QT3DRENDER_QBUFFERCAPTURE_IDX                        = 36,
+    SBK_QT3DRENDER_QBUFFERDATAGENERATOR_IDX                  = 37,
+    SBK_QT3DRENDER_QCAMERA_IDX                               = 38,
+    SBK_QT3DRENDER_QCAMERA_CAMERATRANSLATIONOPTION_IDX       = 39,
+    SBK_QT3DRENDER_QCAMERALENS_IDX                           = 40,
+    SBK_QT3DRENDER_QCAMERALENS_PROJECTIONTYPE_IDX            = 41,
+    SBK_QT3DRENDER_QCAMERASELECTOR_IDX                       = 42,
+    SBK_QT3DRENDER_QCLEARBUFFERS_IDX                         = 43,
+    SBK_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX              = 44,
     SBK_QFLAGS_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX       = 0,
-    SBK_QT3DRENDER_QCLIPPLANE_IDX                            = 44,
-    SBK_QT3DRENDER_QCOLORMASK_IDX                            = 45,
-    SBK_QT3DRENDER_QCOMPUTECOMMAND_IDX                       = 46,
-    SBK_QT3DRENDER_QCULLFACE_IDX                             = 47,
-    SBK_QT3DRENDER_QCULLFACE_CULLINGMODE_IDX                 = 48,
-    SBK_QT3DRENDER_QDEPTHTEST_IDX                            = 49,
-    SBK_QT3DRENDER_QDEPTHTEST_DEPTHFUNCTION_IDX              = 50,
-    SBK_QT3DRENDER_QDIRECTIONALLIGHT_IDX                     = 51,
-    SBK_QT3DRENDER_QDISPATCHCOMPUTE_IDX                      = 52,
-    SBK_QT3DRENDER_QDITHERING_IDX                            = 53,
-    SBK_QT3DRENDER_QEFFECT_IDX                               = 54,
-    SBK_QT3DRENDER_QENVIRONMENTLIGHT_IDX                     = 55,
-    SBK_QT3DRENDER_QFILTERKEY_IDX                            = 56,
-    SBK_QT3DRENDER_QFRAMEGRAPHNODE_IDX                       = 57,
-    SBK_QT3DRENDER_QFRAMEGRAPHNODECREATEDCHANGEBASE_IDX      = 58,
-    SBK_QT3DRENDER_QFRONTFACE_IDX                            = 59,
-    SBK_QT3DRENDER_QFRONTFACE_WINDINGDIRECTION_IDX           = 60,
-    SBK_QT3DRENDER_QFRUSTUMCULLING_IDX                       = 61,
-    SBK_QT3DRENDER_QGEOMETRY_IDX                             = 62,
-    SBK_QT3DRENDER_QGEOMETRYFACTORY_IDX                      = 63,
-    SBK_QT3DRENDER_QGEOMETRYRENDERER_IDX                     = 64,
-    SBK_QT3DRENDER_QGEOMETRYRENDERER_PRIMITIVETYPE_IDX       = 65,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_IDX                    = 66,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_API_IDX                = 67,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_OPENGLPROFILE_IDX      = 68,
-    SBK_QT3DRENDER_QLAYER_IDX                                = 69,
-    SBK_QT3DRENDER_QLAYERFILTER_IDX                          = 70,
-    SBK_QT3DRENDER_QLAYERFILTER_FILTERMODE_IDX               = 71,
-    SBK_QT3DRENDER_QLEVELOFDETAIL_IDX                        = 72,
-    SBK_QT3DRENDER_QLEVELOFDETAIL_THRESHOLDTYPE_IDX          = 73,
-    SBK_QT3DRENDER_QLEVELOFDETAILBOUNDINGSPHERE_IDX          = 74,
-    SBK_QT3DRENDER_QLEVELOFDETAILSWITCH_IDX                  = 75,
-    SBK_QT3DRENDER_QLINEWIDTH_IDX                            = 76,
-    SBK_QT3DRENDER_QMATERIAL_IDX                             = 77,
-    SBK_QT3DRENDER_QMEMORYBARRIER_IDX                        = 78,
-    SBK_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX              = 79,
+    SBK_QT3DRENDER_QCLIPPLANE_IDX                            = 45,
+    SBK_QT3DRENDER_QCOLORMASK_IDX                            = 46,
+    SBK_QT3DRENDER_QCOMPUTECOMMAND_IDX                       = 47,
+    SBK_QT3DRENDER_QCOMPUTECOMMAND_RUNTYPE_IDX               = 48,
+    SBK_QT3DRENDER_QCULLFACE_IDX                             = 49,
+    SBK_QT3DRENDER_QCULLFACE_CULLINGMODE_IDX                 = 50,
+    SBK_QT3DRENDER_QDEPTHTEST_IDX                            = 51,
+    SBK_QT3DRENDER_QDEPTHTEST_DEPTHFUNCTION_IDX              = 52,
+    SBK_QT3DRENDER_QDIRECTIONALLIGHT_IDX                     = 53,
+    SBK_QT3DRENDER_QDISPATCHCOMPUTE_IDX                      = 54,
+    SBK_QT3DRENDER_QDITHERING_IDX                            = 55,
+    SBK_QT3DRENDER_QEFFECT_IDX                               = 56,
+    SBK_QT3DRENDER_QENVIRONMENTLIGHT_IDX                     = 57,
+    SBK_QT3DRENDER_QFILTERKEY_IDX                            = 58,
+    SBK_QT3DRENDER_QFRAMEGRAPHNODE_IDX                       = 59,
+    SBK_QT3DRENDER_QFRAMEGRAPHNODECREATEDCHANGEBASE_IDX      = 60,
+    SBK_QT3DRENDER_QFRONTFACE_IDX                            = 61,
+    SBK_QT3DRENDER_QFRONTFACE_WINDINGDIRECTION_IDX           = 62,
+    SBK_QT3DRENDER_QFRUSTUMCULLING_IDX                       = 63,
+    SBK_QT3DRENDER_QGEOMETRY_IDX                             = 64,
+    SBK_QT3DRENDER_QGEOMETRYFACTORY_IDX                      = 65,
+    SBK_QT3DRENDER_QGEOMETRYRENDERER_IDX                     = 66,
+    SBK_QT3DRENDER_QGEOMETRYRENDERER_PRIMITIVETYPE_IDX       = 67,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_IDX                    = 68,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_API_IDX                = 69,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_OPENGLPROFILE_IDX      = 70,
+    SBK_QT3DRENDER_QLAYER_IDX                                = 71,
+    SBK_QT3DRENDER_QLAYERFILTER_IDX                          = 72,
+    SBK_QT3DRENDER_QLAYERFILTER_FILTERMODE_IDX               = 73,
+    SBK_QT3DRENDER_QLEVELOFDETAIL_IDX                        = 74,
+    SBK_QT3DRENDER_QLEVELOFDETAIL_THRESHOLDTYPE_IDX          = 75,
+    SBK_QT3DRENDER_QLEVELOFDETAILBOUNDINGSPHERE_IDX          = 76,
+    SBK_QT3DRENDER_QLEVELOFDETAILSWITCH_IDX                  = 77,
+    SBK_QT3DRENDER_QLINEWIDTH_IDX                            = 78,
+    SBK_QT3DRENDER_QMATERIAL_IDX                             = 79,
+    SBK_QT3DRENDER_QMEMORYBARRIER_IDX                        = 80,
+    SBK_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX              = 81,
     SBK_QFLAGS_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX       = 1,
-    SBK_QT3DRENDER_QMESH_IDX                                 = 80,
-    SBK_QT3DRENDER_QMESH_STATUS_IDX                          = 81,
-    SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX              = 82,
-    SBK_QT3DRENDER_QNODEPTHMASK_IDX                          = 83,
-    SBK_QT3DRENDER_QNODRAW_IDX                               = 84,
-    SBK_QT3DRENDER_QOBJECTPICKER_IDX                         = 85,
-    SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                  = 86,
-    SBK_QT3DRENDER_QPARAMETER_IDX                            = 87,
-    SBK_QT3DRENDER_QPICKEVENT_IDX                            = 88,
-    SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                    = 89,
-    SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                  = 90,
-    SBK_QT3DRENDER_QPICKLINEEVENT_IDX                        = 91,
-    SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                       = 92,
-    SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                    = 93,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                      = 94,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX           = 96,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX       = 97,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX = 95,
-    SBK_QT3DRENDER_QPOINTLIGHT_IDX                           = 98,
-    SBK_QT3DRENDER_QPOINTSIZE_IDX                            = 99,
-    SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                   = 100,
-    SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                        = 101,
-    SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                      = 102,
-    SBK_QT3DRENDER_QRAYCASTER_IDX                            = 103,
-    SBK_QT3DRENDER_QRAYCASTERHIT_IDX                         = 104,
-    SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                 = 105,
-    SBK_QT3DRENDER_QRENDERASPECT_IDX                         = 106,
-    SBK_QT3DRENDER_QRENDERASPECT_RENDERTYPE_IDX              = 107,
-    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 108,
-    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 109,
-    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 110,
-    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 111,
-    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 112,
-    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 113,
-    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 114,
-    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 115,
-    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 116,
-    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 117,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 118,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 119,
-    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 120,
-    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 121,
-    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 123,
-    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 122,
-    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 124,
-    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 125,
-    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 126,
-    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 127,
-    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 128,
-    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 129,
-    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 130,
-    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 131,
-    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 132,
-    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 133,
-    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 134,
-    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 135,
-    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 136,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 137,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 138,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 139,
-    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 140,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 141,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 142,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 143,
-    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 144,
-    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 145,
-    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 146,
-    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 147,
-    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 148,
-    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 149,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 150,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 151,
-    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 152,
-    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 153,
-    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 154,
-    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 155,
-    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 156,
-    SBK_QT3DRENDER_QTEXTUREGENERATOR_IDX                     = 157,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 158,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 159,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 160,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 161,
-    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 162,
-    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 163,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 164,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 165,
-    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 166,
-    SBK_Qt3DRender_IDX_COUNT                                 = 167
+    SBK_QT3DRENDER_QMESH_IDX                                 = 82,
+    SBK_QT3DRENDER_QMESH_STATUS_IDX                          = 83,
+    SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX              = 84,
+    SBK_QT3DRENDER_QNODEPTHMASK_IDX                          = 85,
+    SBK_QT3DRENDER_QNODRAW_IDX                               = 86,
+    SBK_QT3DRENDER_QOBJECTPICKER_IDX                         = 87,
+    SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                  = 88,
+    SBK_QT3DRENDER_QPARAMETER_IDX                            = 89,
+    SBK_QT3DRENDER_QPICKEVENT_IDX                            = 90,
+    SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                    = 91,
+    SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                  = 92,
+    SBK_QT3DRENDER_QPICKLINEEVENT_IDX                        = 93,
+    SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                       = 94,
+    SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                    = 95,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                      = 96,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX           = 98,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX       = 99,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX = 97,
+    SBK_QT3DRENDER_QPOINTLIGHT_IDX                           = 100,
+    SBK_QT3DRENDER_QPOINTSIZE_IDX                            = 101,
+    SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                   = 102,
+    SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                        = 103,
+    SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                      = 104,
+    SBK_QT3DRENDER_QRAYCASTER_IDX                            = 105,
+    SBK_QT3DRENDER_QRAYCASTERHIT_IDX                         = 106,
+    SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                 = 107,
+    SBK_QT3DRENDER_QRENDERASPECT_IDX                         = 108,
+    SBK_QT3DRENDER_QRENDERASPECT_RENDERTYPE_IDX              = 109,
+    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 110,
+    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 111,
+    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 112,
+    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 113,
+    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 114,
+    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 115,
+    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 116,
+    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 117,
+    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 118,
+    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 119,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 120,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 121,
+    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 122,
+    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 123,
+    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 125,
+    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 124,
+    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 126,
+    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 127,
+    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 128,
+    SBK_QT3DRENDER_QSETFENCE_IDX                             = 129,
+    SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX                  = 130,
+    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 131,
+    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 132,
+    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 133,
+    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 134,
+    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 135,
+    SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX                      = 136,
+    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 137,
+    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 138,
+    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 139,
+    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 140,
+    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 141,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 142,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 143,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 144,
+    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 145,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 146,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 147,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 148,
+    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 149,
+    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 150,
+    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 151,
+    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 152,
+    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 153,
+    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 154,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 155,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 156,
+    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 157,
+    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 158,
+    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 159,
+    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 160,
+    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 161,
+    SBK_QT3DRENDER_QTEXTUREGENERATOR_IDX                     = 162,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 163,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 164,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 165,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 166,
+    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 167,
+    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 168,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 169,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 170,
+    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 171,
+    SBK_QT3DRENDER_QWAITFENCE_IDX                            = 172,
+    SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 173,
+    SBK_Qt3DRender_IDX_COUNT                                 = 174
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_Qt3DRenderTypes;
@@ -394,6 +403,7 @@ template<> inline PyTypeObject* SbkType< ::Qt3DRender::QAbstractTexture::Filter
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QAbstractTexture::CubeMapFace >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTTEXTURE_CUBEMAPFACE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QAbstractTexture::ComparisonFunction >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONFUNCTION_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QAbstractTexture::ComparisonMode >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONMODE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::Qt3DRender::QAbstractTexture::HandleType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTTEXTURE_HANDLETYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QAbstractTexture >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTTEXTURE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QAbstractTextureImage >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QAlphaCoverage >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QALPHACOVERAGE_IDX]); }
@@ -424,6 +434,7 @@ template<> inline PyTypeObject* SbkType< ::QFlags<Qt3DRender::QClearBuffers::Buf
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QClearBuffers >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QCLEARBUFFERS_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QClipPlane >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QCLIPPLANE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QColorMask >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QCOLORMASK_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DRender::QComputeCommand::RunType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QCOMPUTECOMMAND_RUNTYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QComputeCommand >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QCOMPUTECOMMAND_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QCullFace::CullingMode >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QCULLFACE_CULLINGMODE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QCullFace >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QCULLFACE_IDX]); }
@@ -506,11 +517,14 @@ template<> inline PyTypeObject* SbkType< ::Qt3DRender::QSceneLoader >() { return
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QScissorTest >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSCISSORTEST_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QScreenRayCaster >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSCREENRAYCASTER_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QSeamlessCubemap >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DRender::QSetFence::HandleType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::Qt3DRender::QSetFence >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSETFENCE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QShaderData >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERDATA_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QShaderProgram::ShaderType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QShaderProgram::Status >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QShaderProgram >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAM_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QShaderProgramBuilder >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DRender::QSharedGLTexture >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QSortPolicy::SortType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QSortPolicy >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSORTPOLICY_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QSpotLight >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSPOTLIGHT_IDX]); }
@@ -546,6 +560,8 @@ template<> inline PyTypeObject* SbkType< ::Qt3DRender::QTextureRectangle >() { r
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QTextureWrapMode::WrapMode >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QTextureWrapMode >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QViewport >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QVIEWPORT_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DRender::QWaitFence::HandleType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::Qt3DRender::QWaitFence >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QWAITFENCE_IDX]); }
 
 } // namespace Shiboken
 
