@@ -51,45 +51,45 @@
 #include <pyside2_qtpositioning_python.h>
 
 // Binded library includes
-#include <qplacecontactdetail.h>
-#include <qgeoroute.h>
-#include <qplaceresult.h>
-#include <qgeoserviceprovider.h>
-#include <qplacereview.h>
-#include <qplacematchreply.h>
-#include <qplacecontent.h>
-#include <qplaceproposedsearchresult.h>
-#include <qplacematchrequest.h>
-#include <qplaceattribute.h>
-#include <qplacereply.h>
-#include <qplacemanagerengine.h>
-#include <qplaceuser.h>
-#include <qplace.h>
-#include <qplacemanager.h>
-#include <qgeocodingmanagerengine.h>
-#include <qplacecontentreply.h>
-#include <qplacesearchresult.h>
-#include <qplaceimage.h>
-#include <qgeorouterequest.h>
-#include <qplacesearchreply.h>
-#include <qgeoroutingmanager.h>
-#include <qplacesearchrequest.h>
-#include <qplacecontentrequest.h>
-#include <qplaceratings.h>
-#include <qgeoserviceproviderfactory.h>
-#include <qplacedetailsreply.h>
-#include <qplaceidreply.h>
-#include <qplacecategory.h>
-#include <qgeoroutingmanagerengine.h>
-#include <qplacesupplier.h>
-#include <qgeomaneuver.h>
-#include <qgeocodereply.h>
-#include <qgeoroutereply.h>
-#include <qgeocodingmanager.h>
-#include <qplaceeditorial.h>
-#include <qplaceicon.h>
-#include <qgeoroutesegment.h>
-#include <qplacesearchsuggestionreply.h>
+#include <QtLocation/qgeoroutesegment.h>
+#include <QtLocation/qplaceattribute.h>
+#include <QtLocation/qgeoroute.h>
+#include <QtLocation/qplacecontent.h>
+#include <QtLocation/qgeocodingmanagerengine.h>
+#include <QtLocation/qplaceuser.h>
+#include <QtLocation/qgeomaneuver.h>
+#include <QtLocation/qplacecontentrequest.h>
+#include <QtLocation/qplacemanager.h>
+#include <QtLocation/qplaceproposedsearchresult.h>
+#include <QtLocation/qgeoroutingmanagerengine.h>
+#include <QtLocation/qplacecategory.h>
+#include <QtLocation/qplacesearchreply.h>
+#include <QtLocation/qplacematchrequest.h>
+#include <QtLocation/qplacesupplier.h>
+#include <QtLocation/qplaceresult.h>
+#include <QtLocation/qplaceidreply.h>
+#include <QtLocation/qgeorouterequest.h>
+#include <QtLocation/qgeoroutereply.h>
+#include <QtLocation/qplacereview.h>
+#include <QtLocation/qplacecontactdetail.h>
+#include <QtLocation/qplaceeditorial.h>
+#include <QtLocation/qplacesearchrequest.h>
+#include <QtLocation/qplacecontentreply.h>
+#include <QtLocation/qgeoserviceprovider.h>
+#include <QtLocation/qplaceimage.h>
+#include <QtLocation/qgeocodereply.h>
+#include <QtLocation/qplacesearchsuggestionreply.h>
+#include <QtLocation/qplacesearchresult.h>
+#include <QtLocation/qgeoserviceproviderfactory.h>
+#include <QtLocation/qgeoroutingmanager.h>
+#include <QtLocation/qplacematchreply.h>
+#include <QtLocation/qplace.h>
+#include <QtLocation/qgeocodingmanager.h>
+#include <QtLocation/qplacedetailsreply.h>
+#include <QtLocation/qplaceicon.h>
+#include <QtLocation/qplacemanagerengine.h>
+#include <QtLocation/qplacereply.h>
+#include <QtLocation/qplaceratings.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
