@@ -50,43 +50,44 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qnetworkconfiguration.h>
-#include <qpassworddigestor.h>
-#include <qdtls.h>
-#include <qnetworkreply.h>
-#include <qnetworkcookiejar.h>
-#include <qhostaddress.h>
-#include <qnetworkinterface.h>
-#include <qnetworkproxy.h>
-#include <qlocalsocket.h>
-#include <qsslerror.h>
-#include <qsslkey.h>
-#include <qtcpsocket.h>
-#include <qhttpmultipart.h>
-#include <qsslcertificateextension.h>
-#include <qauthenticator.h>
-#include <qhstspolicy.h>
-#include <qnetworkaccessmanager.h>
-#include <qnetworkdatagram.h>
-#include <qssldiffiehellmanparameters.h>
-#include <qsslcertificate.h>
-#include <qabstractsocket.h>
-#include <qnetworkdiskcache.h>
-#include <qsslcipher.h>
-#include <qudpsocket.h>
-#include <qabstractnetworkcache.h>
-#include <qsslpresharedkeyauthenticator.h>
-#include <qsslsocket.h>
-#include <qnetworkcookie.h>
-#include <qnetworkrequest.h>
-#include <qnetworkconfigmanager.h>
-#include <qlocalserver.h>
-#include <qdnslookup.h>
-#include <qssl.h>
-#include <qtcpserver.h>
-#include <qhostinfo.h>
-#include <qnetworksession.h>
-#include <qsslconfiguration.h>
+#include <QtNetwork/qnetworkconfigmanager.h>
+#include <QtNetwork/qnetworkaccessmanager.h>
+#include <QtNetwork/qsslcertificate.h>
+#include <QtNetwork/qnetworkcookie.h>
+#include <QtNetwork/qabstractnetworkcache.h>
+#include <QtNetwork/qnetworkdiskcache.h>
+#include <QtNetwork/qnetworkdatagram.h>
+#include <QtNetwork/qsslkey.h>
+#include <QtNetwork/qabstractsocket.h>
+#include <QtNetwork/qsslerror.h>
+#include <QtNetwork/qnetworkreply.h>
+#include <QtNetwork/qnetworkproxy.h>
+#include <QtNetwork/qnetworksession.h>
+#include <QtNetwork/qhostinfo.h>
+#include <QtNetwork/qlocalserver.h>
+#include <QtNetwork/qudpsocket.h>
+#include <QtNetwork/qtcpserver.h>
+#include <QtNetwork/qsslconfiguration.h>
+#include <QtNetwork/qdnslookup.h>
+#include <QtNetwork/qsslcertificateextension.h>
+#include <QtNetwork/qdtls.h>
+#include <QtNetwork/qpassworddigestor.h>
+#include <QtNetwork/qhostaddress.h>
+#include <QtNetwork/qhttpmultipart.h>
+#include <QtNetwork/qnetworkconfiguration.h>
+#include <QtNetwork/qocspresponse.h>
+#include <QtNetwork/qauthenticator.h>
+#include <QtNetwork/qnetworkinterface.h>
+#include <QtNetwork/qssldiffiehellmanparameters.h>
+#include <QtNetwork/qssl.h>
+#include <QtNetwork/qlocalsocket.h>
+#include <QtNetwork/qsslsocket.h>
+#include <QtNetwork/qsslpresharedkeyauthenticator.h>
+#include <QtNetwork/qtcpsocket.h>
+#include <QtNetwork/qsslcipher.h>
+#include <QtNetwork/qhstspolicy.h>
+#include <QtNetwork/qnetworkcookiejar.h>
+#include <QtNetwork/qnetworkrequest.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -193,35 +194,38 @@ enum : int {
     SBK_QNETWORKSESSION_SESSIONERROR_IDX                     = 85,
     SBK_QNETWORKSESSION_USAGEPOLICY_IDX                      = 87,
     SBK_QFLAGS_QNETWORKSESSION_USAGEPOLICY_IDX               = 30,
-    SBK_QPASSWORDDIGESTOR_IDX                                = 88,
-    SBK_QSSL_IDX                                             = 91,
-    SBK_QSSL_KEYTYPE_IDX                                     = 95,
-    SBK_QSSL_ENCODINGFORMAT_IDX                              = 93,
-    SBK_QSSL_KEYALGORITHM_IDX                                = 94,
-    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 92,
-    SBK_QSSL_SSLPROTOCOL_IDX                                 = 97,
-    SBK_QSSL_SSLOPTION_IDX                                   = 96,
+    SBK_QOCSPRESPONSE_IDX                                    = 89,
+    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 91,
+    SBK_QtNetworkQSSL_IDX                                    = 94,
+    SBK_QSSL_KEYTYPE_IDX                                     = 98,
+    SBK_QSSL_ENCODINGFORMAT_IDX                              = 96,
+    SBK_QSSL_KEYALGORITHM_IDX                                = 97,
+    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 95,
+    SBK_QSSL_SSLPROTOCOL_IDX                                 = 100,
+    SBK_QSSL_SSLOPTION_IDX                                   = 99,
     SBK_QFLAGS_QSSL_SSLOPTION_IDX                            = 31,
-    SBK_QSSLCERTIFICATE_IDX                                  = 98,
-    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 99,
-    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 100,
-    SBK_QSSLCIPHER_IDX                                       = 101,
-    SBK_QSSLCONFIGURATION_IDX                                = 102,
-    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 103,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 104,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 105,
-    SBK_QSSLERROR_IDX                                        = 106,
-    SBK_QSSLERROR_SSLERROR_IDX                               = 107,
-    SBK_QSSLKEY_IDX                                          = 108,
-    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 109,
-    SBK_QSSLSOCKET_IDX                                       = 110,
-    SBK_QSSLSOCKET_SSLMODE_IDX                               = 112,
-    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 111,
-    SBK_QTCPSERVER_IDX                                       = 113,
-    SBK_QTCPSOCKET_IDX                                       = 114,
-    SBK_QUDPSOCKET_IDX                                       = 115,
+    SBK_QSSLCERTIFICATE_IDX                                  = 101,
+    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 102,
+    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 103,
+    SBK_QSSLCIPHER_IDX                                       = 104,
+    SBK_QSSLCONFIGURATION_IDX                                = 105,
+    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 106,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 107,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 108,
+    SBK_QSSLERROR_IDX                                        = 109,
+    SBK_QSSLERROR_SSLERROR_IDX                               = 110,
+    SBK_QSSLKEY_IDX                                          = 111,
+    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 112,
+    SBK_QSSLSOCKET_IDX                                       = 113,
+    SBK_QSSLSOCKET_SSLMODE_IDX                               = 115,
+    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 114,
+    SBK_QTCPSERVER_IDX                                       = 116,
+    SBK_QTCPSOCKET_IDX                                       = 117,
+    SBK_QUDPSOCKET_IDX                                       = 118,
     SBK_QDTLSERROR_IDX                                       = 20,
-    SBK_QtNetwork_IDX_COUNT                                  = 116
+    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 88,
+    SBK_QOCSPREVOCATIONREASON_IDX                            = 90,
+    SBK_QtNetwork_IDX_COUNT                                  = 119
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtNetworkTypes;
@@ -260,10 +264,11 @@ enum : int {
     SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 23, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
     SBK_QTNETWORK_QMAP_QBYTEARRAY_QVARIANT_IDX               = 24, // QMap<QByteArray,QVariant >
     SBK_QTNETWORK_QLIST_QSSLCIPHER_IDX                       = 25, // QList<QSslCipher >
-    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 26, // QList<QVariant >
-    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 27, // QList<QString >
-    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 28, // QMap<QString,QVariant >
-    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 29
+    SBK_QTNETWORK_QVECTOR_QOCSPRESPONSE_IDX                  = 26, // QVector<QOcspResponse >
+    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 27, // QList<QVariant >
+    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 28, // QList<QString >
+    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 29, // QMap<QString,QVariant >
+    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 30
 };
 // Macros for type check
 
@@ -272,6 +277,8 @@ namespace Shiboken
 
 // PyType functions, to get the PyObjectType for a type T
 template<> inline PyTypeObject* SbkType< ::QDtlsError >() { return SbkPySide2_QtNetworkTypes[SBK_QDTLSERROR_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QOcspCertificateStatus >() { return SbkPySide2_QtNetworkTypes[SBK_QOCSPCERTIFICATESTATUS_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QOcspRevocationReason >() { return SbkPySide2_QtNetworkTypes[SBK_QOCSPREVOCATIONREASON_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QAbstractNetworkCache >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtNetworkTypes[SBK_QABSTRACTNETWORKCACHE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QAbstractSocket::SocketType >() { return SbkPySide2_QtNetworkTypes[SBK_QABSTRACTSOCKET_SOCKETTYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QAbstractSocket::NetworkLayerProtocol >() { return SbkPySide2_QtNetworkTypes[SBK_QABSTRACTSOCKET_NETWORKLAYERPROTOCOL_IDX]; }
@@ -358,6 +365,7 @@ template<> inline PyTypeObject* SbkType< ::QNetworkSession::SessionError >() { r
 template<> inline PyTypeObject* SbkType< ::QNetworkSession::UsagePolicy >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKSESSION_USAGEPOLICY_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QFlags<QNetworkSession::UsagePolicy> >() { return SbkPySide2_QtNetworkTypes[SBK_QFLAGS_QNETWORKSESSION_USAGEPOLICY_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QNetworkSession >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtNetworkTypes[SBK_QNETWORKSESSION_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QOcspResponse >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtNetworkTypes[SBK_QOCSPRESPONSE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QSsl::KeyType >() { return SbkPySide2_QtNetworkTypes[SBK_QSSL_KEYTYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QSsl::EncodingFormat >() { return SbkPySide2_QtNetworkTypes[SBK_QSSL_ENCODINGFORMAT_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QSsl::KeyAlgorithm >() { return SbkPySide2_QtNetworkTypes[SBK_QSSL_KEYALGORITHM_IDX]; }
