@@ -46,64 +46,63 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qwebchannel.h>
-#include <qwebchannelabstracttransport.h>
+#include <QtWebChannel/qwebchannel.h>
+#include <QtWebChannel/qwebchannelabstracttransport.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
-#include <signalmanager.h>
 #include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QStack>
+#include <pysideqflags.h>
+#include <QLinkedList>
 #include <QList>
 #include <QMap>
-#include <pysideqflags.h>
+#include <QMultiMap>
 #include <QPair>
 #include <QQueue>
-#include <QMultiMap>
 #include <QSet>
-#include <QLinkedList>
+#include <QStack>
 #include <QVector>
 
 // Type indices
-#define SBK_QWEBCHANNELABSTRACTTRANSPORT_IDX                         1
-#define SBK_QWEBCHANNEL_IDX                                          0
-#define SBK_QtWebChannel_IDX_COUNT                                   2
-
+enum : int {
+    SBK_QWEBCHANNEL_IDX                                      = 0,
+    SBK_QWEBCHANNELABSTRACTTRANSPORT_IDX                     = 1,
+    SBK_QtWebChannel_IDX_COUNT                               = 2
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtWebChannelTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtWebChannelModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtWebChannelTypeConverters;
 
 // Converter indices
-#define SBK_QTWEBCHANNEL_QLIST_QOBJECTPTR_IDX                        0 // const QList<QObject* > &
-#define SBK_QTWEBCHANNEL_QLIST_QBYTEARRAY_IDX                        1 // QList<QByteArray >
-#define SBK_QTWEBCHANNEL_QHASH_QSTRING_QOBJECTPTR_IDX                2 // const QHash<QString,QObject* > &
-#define SBK_QTWEBCHANNEL_QLIST_QVARIANT_IDX                          3 // QList<QVariant >
-#define SBK_QTWEBCHANNEL_QLIST_QSTRING_IDX                           4 // QList<QString >
-#define SBK_QTWEBCHANNEL_QMAP_QSTRING_QVARIANT_IDX                   5 // QMap<QString,QVariant >
-#define SBK_QtWebChannel_CONVERTERS_IDX_COUNT                        6
-
+enum : int {
+    SBK_QTWEBCHANNEL_QLIST_QOBJECTPTR_IDX                    = 0, // const QList<QObject* > &
+    SBK_QTWEBCHANNEL_QLIST_QBYTEARRAY_IDX                    = 1, // QList<QByteArray >
+    SBK_QTWEBCHANNEL_QHASH_QSTRING_QOBJECTPTR_IDX            = 2, // const QHash<QString,QObject* > &
+    SBK_QTWEBCHANNEL_QLIST_QVARIANT_IDX                      = 3, // QList<QVariant >
+    SBK_QTWEBCHANNEL_QLIST_QSTRING_IDX                       = 4, // QList<QString >
+    SBK_QTWEBCHANNEL_QMAP_QSTRING_QVARIANT_IDX               = 5, // QMap<QString,QVariant >
+    SBK_QtWebChannel_CONVERTERS_IDX_COUNT                    = 6
+};
 // Macros for type check
 
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QWebChannelAbstractTransport >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebChannelTypes[SBK_QWEBCHANNELABSTRACTTRANSPORT_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QWebChannel >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebChannelTypes[SBK_QWEBCHANNEL_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QWebChannelAbstractTransport >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebChannelTypes[SBK_QWEBCHANNELABSTRACTTRANSPORT_IDX]); }
 
 } // namespace Shiboken
 
